@@ -35,7 +35,6 @@ class SpellBot(AutoShardedBot):
     def __init__(
         self,
         mock_games: bool = False,
-        interactive: bool = False,
         create_connection: bool = True,
     ) -> None:
         intents = discord.Intents().default()
@@ -48,7 +47,6 @@ class SpellBot(AutoShardedBot):
             kwargs["application_id"] = int(settings.BOT_APPLICATION_ID)
         super().__init__(command_prefix="!", help_command=None, intents=intents, **kwargs)
         self.mock_games = mock_games
-        self.interactive = interactive
         self.create_connection = create_connection
         self.guild_locks = TTLCache[int, asyncio.Lock](maxsize=100, ttl=3600)  # 1 hr
 
@@ -85,12 +83,15 @@ class SpellBot(AutoShardedBot):
 
     @tracer.wrap()
     async def create_game_link(self, game: GameDict) -> GameLinkDetails:
+        if span := tracer.current_span():
+            span.set_tag("link_service", GameService(game["service"]).name)
+
         if self.mock_games:
             return GameLinkDetails(f"http://exmaple.com/game/{uuid4()}")
         service = game.get("service")
         if service == GameService.SPELLTABLE.value:
             if settings.ENABLE_SPELLTABLE:
-                link = await generate_spelltable_link(game, interactive=self.interactive)
+                link = await generate_spelltable_link(game)
                 return GameLinkDetails(link)
             # fallback to tablestream if spelltable is disabled
             service = GameService.TABLE_STREAM.value
@@ -193,12 +194,10 @@ class SpellBot(AutoShardedBot):
 
 def build_bot(
     mock_games: bool = False,
-    interactive: bool = False,
     create_connection: bool = True,
 ) -> SpellBot:
     bot = SpellBot(
         mock_games=mock_games,
-        interactive=interactive,
         create_connection=create_connection,
     )
     setup_metrics()
