@@ -1,10 +1,12 @@
-"""Adds removeable role awards
+"""
+Adds removeable role awards.
 
 Revision ID: 42f55401ef2b
 Revises: 6e982c9318a6
 Create Date: 2021-12-31 17:50:24.259796
 
 """
+
 import sqlalchemy as sa
 from alembic import op
 
@@ -15,7 +17,7 @@ branch_labels = None
 depends_on = None
 
 
-def upgrade():
+def upgrade() -> None:
     op.add_column(
         "guild_awards",
         sa.Column(
@@ -27,5 +29,5 @@ def upgrade():
     )
 
 
-def downgrade():
+def downgrade() -> None:
     op.drop_column("guild_awards", "remove")
