@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from datetime import datetime
+from datetime import UTC, datetime
+from functools import partial
 from typing import TYPE_CHECKING, TypedDict, cast
 
 from sqlalchemy import BigInteger, Boolean, Column, DateTime, String, false, null
@@ -27,6 +28,8 @@ class GuildDict(TypedDict):
     awards: list[GuildAwardDict]
     banned: bool
     notice: str
+    suggest_voice_category: str
+    enable_mythic_track: bool
 
 
 class Guild(Base):
@@ -34,20 +37,20 @@ class Guild(Base):
 
     __tablename__ = "guilds"
 
-    xid: int = cast(int, Column(BigInteger, primary_key=True, nullable=False))
+    xid: int = cast("int", Column(BigInteger, primary_key=True, nullable=False))
     created_at = Column(
         DateTime,
         nullable=False,
-        default=datetime.utcnow,
+        default=partial(datetime.now, UTC),
         server_default=now,
         doc="UTC timestamp when this guild was first created",
     )
     updated_at = Column(
         DateTime,
         nullable=False,
-        default=datetime.utcnow,
+        default=partial(datetime.now, UTC),
         server_default=now,
-        onupdate=datetime.utcnow,
+        onupdate=partial(datetime.now, UTC),
         doc="UTC timestamp when this guild was last updated",
     )
     name = Column(
@@ -93,6 +96,20 @@ class Guild(Base):
         default=None,
         server_default=null(),
     )
+    suggest_voice_category = Column(
+        String(100),
+        doc="Category to use when suggesting voice channels for games",
+        nullable=True,
+        default=None,
+        server_default=null(),
+    )
+    enable_mythic_track = Column(
+        Boolean,
+        nullable=False,
+        default=False,
+        server_default=false(),
+        doc="If true, enable mythic track for this guild",
+    )
 
     games = relationship(
         "Game",
@@ -134,4 +151,6 @@ class Guild(Base):
             ),
             "banned": self.banned,
             "notice": self.notice,
+            "suggest_voice_category": self.suggest_voice_category,
+            "enable_mythic_track": self.enable_mythic_track,
         }
