@@ -1,12 +1,14 @@
 from __future__ import annotations
 
 import logging
+import random
 from asyncio import sleep
+from dataclasses import dataclass
 from typing import TYPE_CHECKING, Any, cast
 
 import discord
 from aiohttp.client_exceptions import ClientOSError
-from ddtrace import tracer
+from ddtrace.trace import tracer
 from discord.errors import DiscordException
 from discord.utils import MISSING
 
@@ -174,7 +176,7 @@ def safe_get_partial_message(
         return None
 
     message: discord.PartialMessage | None = None
-    text_channel = cast(discord.TextChannel, channel)
+    text_channel = cast("discord.TextChannel", channel)
     with suppress(
         DiscordException,
         ClientOSError,
@@ -505,7 +507,7 @@ async def safe_channel_reply(
 
 
 @tracer.wrap()
-async def save_create_channel_invite(
+async def safe_create_channel_invite(
     channel: discord.abc.GuildChannel,
     *args: Any,
     **kwargs: Any,
@@ -621,11 +623,11 @@ async def safe_add_role(
 
     try:
         member = cast(
-            discord.Member | None,
+            "discord.Member | None",
             (
                 user_or_member
                 if hasattr(user_or_member, "roles")
-                else guild.get_member(cast(discord.User, user_or_member).id)
+                else guild.get_member(cast("discord.User", user_or_member).id)
             ),
         )
         if not member or not hasattr(member, "roles"):
@@ -672,3 +674,37 @@ async def safe_add_role(
             guild.id,
             str(user_or_member),
         )
+
+
+@dataclass
+class VoiceChannelSuggestion:
+    already_picked: int | None = None
+    random_empty: int | None = None
+
+    def get(self) -> int | None:
+        return self.already_picked or self.random_empty
+
+
+def safe_suggest_voice_channel(
+    *,
+    guild: discord.Guild | None,
+    category: str,
+    player_xids: list[int],
+) -> VoiceChannelSuggestion:
+    if guild is None:
+        return VoiceChannelSuggestion()
+
+    empty_channels = []
+    random_empty = None
+    already_picked = None
+    for vc in guild.voice_channels:
+        if not vc.category or not vc.category.name.lower().startswith(category.lower()):
+            continue
+        member_xids = {m.id for m in vc.members}
+        if any(player_xid in member_xids for player_xid in player_xids):
+            already_picked = vc.id
+            break
+        if not member_xids:
+            empty_channels.append(vc.id)
+    random_empty = random.choice(empty_channels) if empty_channels else None  # noqa: S311
+    return VoiceChannelSuggestion(already_picked, random_empty)
