@@ -37,8 +37,10 @@ class Settings:
         "MOD_PREFIX",
         "PENDING_EMBED_COLOR",
         "PORT",
-        "REDISCLOUD_URL",
+        "REDIS_URL",
+        "SPELLTABLE_API_KEY",
         "SPELLTABLE_AUTH_KEY",
+        "SPELLTABLE_CLIENT_ID",
         "SPELLTABLE_CREATE",
         "SPELLTABLE_PASSES",
         "SPELLTABLE_ROOT",
@@ -90,13 +92,15 @@ class Settings:
         self.DATABASE_URL = database_url
 
         # cache
-        self.REDISCLOUD_URL = getenv("REDISCLOUD_URL")
+        self.REDIS_URL = getenv("REDIS_URL")
 
         # spelltable
         self.ENABLE_SPELLTABLE = getenv("ENABLE_SPELLTABLE", "true").lower() == "true"
         self.SPELLTABLE_ROOT = "https://us-central1-magic-night-30324.cloudfunctions.net"
         self.SPELLTABLE_CREATE = f"{self.SPELLTABLE_ROOT}/createGame"
         self.SPELLTABLE_AUTH_KEY = getenv("SPELLTABLE_AUTH_KEY")
+        self.SPELLTABLE_API_KEY = getenv("SPELLTABLE_API_KEY")
+        self.SPELLTABLE_CLIENT_ID = getenv("SPELLTABLE_CLIENT_ID")
 
         # spelltable headless
         self.SPELLTABLE_USERS = getenv("SPELLTABLE_USERS")
